#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.wncklet"), aligned (8)))
#else
# define SECTION
#endif

static const SECTION union { const guint8 data[4836]; const double alignment; void * const ptr;}  wncklet_resource_data = { {
  0x47, 0x56, 0x61, 0x72, 0x69, 0x61, 0x6e, 0x74, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x18, 0x00, 0x00, 0x00, 0x38, 0x01, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x28, 0x0a, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x03, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 
  0x05, 0x00, 0x00, 0x00, 0x05, 0x00, 0x00, 0x00, 
  0x06, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 
  0x09, 0x00, 0x00, 0x00, 0x0a, 0x00, 0x00, 0x00, 
  0xd4, 0xb5, 0x02, 0x00, 0xff, 0xff, 0xff, 0xff, 
  0x38, 0x01, 0x00, 0x00, 0x01, 0x00, 0x4c, 0x00, 
  0x3c, 0x01, 0x00, 0x00, 0x40, 0x01, 0x00, 0x00, 
  0x6f, 0xd8, 0xf6, 0x94, 0x09, 0x00, 0x00, 0x00, 
  0x40, 0x01, 0x00, 0x00, 0x06, 0x00, 0x4c, 0x00, 
  0x48, 0x01, 0x00, 0x00, 0x4c, 0x01, 0x00, 0x00, 
  0x0d, 0xdb, 0xe8, 0xa7, 0x04, 0x00, 0x00, 0x00, 
  0x4c, 0x01, 0x00, 0x00, 0x14, 0x00, 0x76, 0x00, 
  0x60, 0x01, 0x00, 0x00, 0xef, 0x01, 0x00, 0x00, 
  0x98, 0x25, 0x49, 0x37, 0x04, 0x00, 0x00, 0x00, 
  0xef, 0x01, 0x00, 0x00, 0x0e, 0x00, 0x76, 0x00, 
  0x00, 0x02, 0x00, 0x00, 0x0f, 0x0a, 0x00, 0x00, 
  0xab, 0x9c, 0xb2, 0x71, 0x06, 0x00, 0x00, 0x00, 
  0x0f, 0x0a, 0x00, 0x00, 0x08, 0x00, 0x4c, 0x00, 
  0x18, 0x0a, 0x00, 0x00, 0x28, 0x0a, 0x00, 0x00, 
  0x4b, 0x50, 0x90, 0x0b, 0x00, 0x00, 0x00, 0x00, 
  0x28, 0x0a, 0x00, 0x00, 0x04, 0x00, 0x4c, 0x00, 
  0x2c, 0x0a, 0x00, 0x00, 0x30, 0x0a, 0x00, 0x00, 
  0x44, 0x9f, 0x99, 0xd8, 0x01, 0x00, 0x00, 0x00, 
  0x30, 0x0a, 0x00, 0x00, 0x07, 0x00, 0x4c, 0x00, 
  0x38, 0x0a, 0x00, 0x00, 0x3c, 0x0a, 0x00, 0x00, 
  0xbc, 0x25, 0x86, 0x61, 0x04, 0x00, 0x00, 0x00, 
  0x3c, 0x0a, 0x00, 0x00, 0x15, 0x00, 0x76, 0x00, 
  0x58, 0x0a, 0x00, 0x00, 0x67, 0x12, 0x00, 0x00, 
  0x31, 0x66, 0x16, 0x9f, 0x04, 0x00, 0x00, 0x00, 
  0x67, 0x12, 0x00, 0x00, 0x1b, 0x00, 0x76, 0x00, 
  0x88, 0x12, 0x00, 0x00, 0xd7, 0x12, 0x00, 0x00, 
  0xb0, 0xb7, 0x24, 0x30, 0x05, 0x00, 0x00, 0x00, 
  0xd7, 0x12, 0x00, 0x00, 0x06, 0x00, 0x4c, 0x00, 
  0xe0, 0x12, 0x00, 0x00, 0xe4, 0x12, 0x00, 0x00, 
  0x2f, 0x00, 0x00, 0x00, 0x05, 0x00, 0x00, 0x00, 
  0x70, 0x61, 0x6e, 0x65, 0x6c, 0x2f, 0x00, 0x00, 
  0x06, 0x00, 0x00, 0x00, 0x77, 0x69, 0x6e, 0x64, 
  0x6f, 0x77, 0x2d, 0x6c, 0x69, 0x73, 0x74, 0x2d, 
  0x6d, 0x65, 0x6e, 0x75, 0x2e, 0x78, 0x6d, 0x6c, 
  0x4c, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x78, 0xda, 0xb3, 0xc9, 0x4d, 0xcd, 0x2b, 0xcd, 
  0x2c, 0x49, 0xcd, 0x55, 0xc8, 0x4b, 0xcc, 0x4d, 
  0xb5, 0x55, 0x0a, 0x49, 0x2c, 0xce, 0xce, 0xc9, 
  0x2c, 0x2e, 0x51, 0x08, 0x28, 0x4a, 0x4d, 0x4b, 
  0x2d, 0x4a, 0xcd, 0x4b, 0x4e, 0x2d, 0x56, 0xf0, 
  0x04, 0xca, 0x2b, 0x29, 0x24, 0x26, 0x97, 0x64, 
  0xe6, 0xe7, 0x21, 0x94, 0x20, 0xa9, 0x50, 0x52, 
  0xd0, 0xb7, 0xe3, 0xe2, 0x02, 0x00, 0x36, 0x3d, 
  0x1a, 0xf4, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x28, 0x75, 0x75, 0x61, 0x79, 0x29, 0x77, 
  0x69, 0x6e, 0x64, 0x6f, 0x77, 0x2d, 0x6c, 0x69, 
  0x73, 0x74, 0x2e, 0x75, 0x69, 0x00, 0x00, 0x00, 
  0x0d, 0x3d, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x78, 0xda, 0xed, 0x5b, 0xdd, 0x73, 0xe2, 0x36, 
  0x10, 0x7f, 0xbf, 0xbf, 0x42, 0xd5, 0x6b, 0xc7, 
  0x47, 0x20, 0xed, 0xb5, 0x9d, 0x01, 0xdf, 0x24, 
  0xbd, 0x34, 0x77, 0x73, 0xf9, 0x9a, 0x24, 0xed, 
  0x3d, 0x6a, 0x84, 0xbd, 0x80, 0x8a, 0x90, 0x5c, 
  0x49, 0x86, 0xa4, 0xd3, 0x3f, 0xbe, 0xb2, 0x4d, 
  0x02, 0x01, 0x19, 0x6c, 0xe3, 0x24, 0x97, 0xc4, 
  0x6f, 0xd8, 0xd2, 0x6f, 0xbd, 0xdf, 0xab, 0x5d, 
  0xec, 0xee, 0xc7, 0x9b, 0x09, 0x47, 0x53, 0x50, 
  0x9a, 0x49, 0xd1, 0xc3, 0xed, 0xf7, 0x7b, 0xf8, 
  0xa3, 0xff, 0xae, 0xcb, 0x84, 0x01, 0x35, 0xa0, 
  0x01, 0xf8, 0xef, 0x10, 0xea, 0x2a, 0xf8, 0x27, 
  0x66, 0x0a, 0x34, 0xe2, 0xac, 0xdf, 0xc3, 0x43, 
  0x33, 0xfe, 0x11, 0x2f, 0x20, 0x9d, 0xf7, 0xed, 
  0x0f, 0xb8, 0x95, 0xee, 0xfb, 0xc1, 0xf3, 0xd0, 
  0x3d, 0xd2, 0x13, 0x74, 0xc2, 0xc4, 0xd0, 0x8b, 
  0x24, 0x67, 0xc1, 0x2d, 0x32, 0x32, 0xe2, 0x30, 
  0x05, 0xee, 0x05, 0xd2, 0xee, 0xb8, 0x31, 0x31, 
  0xe5, 0xc8, 0xf3, 0x52, 0x98, 0xec, 0xff, 0x0d, 
  0x81, 0x41, 0x01, 0xa7, 0x5a, 0xf7, 0xf0, 0xb1, 
  0x19, 0x7f, 0x62, 0x94, 0xcb, 0x21, 0x46, 0x2c, 
  0xec, 0x61, 0x43, 0xf5, 0x98, 0x33, 0x6d, 0x48, 
  0xa4, 0x64, 0x04, 0xca, 0x30, 0xd0, 0x24, 0xcc, 
  0xd6, 0x13, 0xb0, 0x85, 0xcf, 0x17, 0x6e, 0x91, 
  0x7d, 0x20, 0xf4, 0x70, 0x5f, 0xaa, 0x10, 0x14, 
  0x99, 0xb1, 0xd0, 0x8c, 0xb0, 0xff, 0x73, 0xb7, 
  0x75, 0xb7, 0xee, 0xde, 0x6e, 0x98, 0xe1, 0x80, 
  0x91, 0x51, 0x54, 0x68, 0x4e, 0x0d, 0xed, 0x73, 
  0x7b, 0xf3, 0x16, 0x34, 0xf6, 0xbf, 0x31, 0x11, 
  0xca, 0x19, 0x3a, 0xb1, 0x0f, 0x47, 0x17, 0x0a, 
  0x06, 0xa0, 0x40, 0x04, 0xa0, 0xb7, 0x12, 0xbc, 
  0x8d, 0x80, 0x8c, 0xac, 0x1a, 0xb0, 0x2f, 0xa4, 
  0x9a, 0x50, 0xbe, 0x06, 0x08, 0x46, 0x8c, 0x87, 
  0x99, 0xa2, 0x04, 0xb5, 0x0a, 0x49, 0x2e, 0x7b, 
  0x78, 0xda, 0x97, 0x37, 0x73, 0x91, 0x5c, 0x3a, 
  0xf9, 0xeb, 0xd0, 0x2e, 0xa7, 0x1a, 0xc9, 0xa4, 
  0xf7, 0x92, 0xfd, 0x9d, 0x7b, 0xc0, 0x3a, 0x1f, 
  0x53, 0xa6, 0x99, 0x15, 0x06, 0xfb, 0xd7, 0x2a, 
  0x86, 0x55, 0x1e, 0x5c, 0x00, 0xa9, 0x18, 0x08, 
  0x43, 0x8d, 0xb5, 0x2a, 0xf6, 0xa7, 0x89, 0xaa, 
  0x83, 0x75, 0xe6, 0x5d, 0x40, 0x1d, 0xd1, 0xc0, 
  0x5a, 0x1a, 0xfb, 0x1d, 0xe7, 0xee, 0x54, 0xbe, 
  0xc5, 0xf5, 0x66, 0xe1, 0x12, 0xa9, 0xda, 0x78, 
  0x79, 0x77, 0x05, 0xc9, 0x5c, 0x20, 0xeb, 0x7b, 
  0xc2, 0x58, 0xab, 0x1e, 0x7f, 0xfa, 0x4a, 0x2e, 
  0xce, 0xbf, 0x9c, 0x5d, 0x1f, 0x5d, 0x92, 0xd3, 
  0xf3, 0xeb, 0x2f, 0xe7, 0x67, 0xe4, 0xf4, 0xe0, 
  0xea, 0x2b, 0xfa, 0x0f, 0x39, 0x56, 0x3e, 0xdb, 
  0xab, 0xe5, 0xe5, 0xc3, 0x3f, 0xaf, 0xaf, 0xed, 
  0xed, 0x8b, 0xcb, 0xa3, 0xab, 0x2b, 0xc7, 0xfd, 
  0xcb, 0xa3, 0x93, 0xa3, 0x83, 0xab, 0xa3, 0x74, 
  0xa5, 0x28, 0x5f, 0x5b, 0xdc, 0x75, 0x67, 0x63, 
  0x6d, 0x34, 0x58, 0xfb, 0xd7, 0x5c, 0xc8, 0x9a, 
  0xd5, 0x8a, 0x58, 0xee, 0x17, 0xbc, 0x8a, 0xa8, 
  0x68, 0xbd, 0x9d, 0x45, 0xde, 0x28, 0xf6, 0x87, 
  0x8d, 0x28, 0xa7, 0xe4, 0x6e, 0xe9, 0x4f, 0x68, 
  0x1f, 0x78, 0x26, 0x3e, 0x4f, 0x7e, 0xb6, 0xb1, 
  0x0b, 0xb7, 0x83, 0x0e, 0x5c, 0xe0, 0x1b, 0xca, 
  0xd9, 0xd0, 0xaa, 0x60, 0xaf, 0x2c, 0x90, 0x67, 
  0xdc, 0x6e, 0x49, 0x75, 0xbf, 0x27, 0xf9, 0x59, 
  0x98, 0xad, 0xc4, 0xa9, 0x31, 0x8a, 0xf5, 0x63, 
  0x03, 0xda, 0xbd, 0x61, 0x79, 0xcb, 0x9c, 0x81, 
  0x19, 0xb0, 0xe1, 0xc8, 0xd8, 0xda, 0x41, 0x79, 
  0x9c, 0xba, 0x3e, 0x0f, 0xb3, 0xca, 0xe1, 0xc0, 
  0xb6, 0x36, 0xd3, 0xef, 0xb6, 0x32, 0x63, 0x38, 
  0xd7, 0xac, 0x9d, 0xc7, 0xd6, 0xd0, 0xc5, 0xb4, 
  0x02, 0x37, 0x11, 0x15, 0x21, 0xf6, 0xff, 0xa0, 
  0x5c, 0x97, 0xb6, 0xc5, 0x80, 0x71, 0x5e, 0x11, 
  0x1a, 0x49, 0xcd, 0x32, 0x5f, 0xde, 0x62, 0x48, 
  0xbb, 0x9a, 0x27, 0x4f, 0xb7, 0x95, 0xe3, 0xac, 
  0x65, 0x9c, 0xf8, 0x20, 0x71, 0xa7, 0x89, 0x35, 
  0x79, 0xe6, 0xc8, 0xf4, 0xee, 0xf2, 0x49, 0x9c, 
  0xf9, 0x7b, 0x49, 0xcb, 0xb9, 0x31, 0x03, 0x03, 
  0x7b, 0xf4, 0xa0, 0x61, 0x98, 0xe5, 0xcb, 0xce, 
  0x56, 0x7c, 0xae, 0xe2, 0x8b, 0xe4, 0xcf, 0xdf, 
  0x70, 0x1e, 0x72, 0x47, 0xb5, 0xd7, 0x92, 0x4f, 
  0x77, 0xcb, 0xab, 0xc5, 0x34, 0xe4, 0xd6, 0xd2, 
  0x25, 0x0d, 0x99, 0x3c, 0x8c, 0x8d, 0xb1, 0xac, 
  0xa6, 0xca, 0xd2, 0x23, 0x39, 0x23, 0x41, 0xac, 
  0xec, 0x91, 0xcc, 0x10, 0x95, 0xac, 0xe2, 0x4d, 
  0x14, 0xcb, 0xe4, 0xc2, 0xab, 0x11, 0xb1, 0xa9, 
  0x70, 0x96, 0x66, 0x44, 0x8d, 0x06, 0x4a, 0x4e, 
  0xd0, 0xfc, 0x41, 0x68, 0x26, 0xd5, 0x38, 0x11, 
  0xb6, 0x90, 0xba, 0x6b, 0xb1, 0x99, 0x8b, 0x48, 
  0x40, 0x05, 0x19, 0xc8, 0x20, 0xd6, 0xbb, 0x91, 
  0x51, 0x10, 0x00, 0x9b, 0x26, 0xa7, 0x69, 0x18, 
  0xd0, 0x98, 0x9b, 0x82, 0x69, 0x2c, 0x8f, 0x5c, 
  0xac, 0x81, 0xc4, 0xc2, 0x1e, 0x65, 0x38, 0x13, 
  0x3b, 0x0a, 0x18, 0x2a, 0x3a, 0x23, 0x56, 0xff, 
  0xd6, 0x1f, 0x8d, 0x54, 0x65, 0x68, 0x6d, 0xaa, 
  0x0a, 0xc5, 0xaa, 0x43, 0x2d, 0x55, 0xa2, 0x86, 
  0x6a, 0xb1, 0x73, 0xd5, 0x28, 0x50, 0x3d, 0xb6, 
  0x56, 0x91, 0xfa, 0x43, 0x96, 0x72, 0x5e, 0x7b, 
  0xb8, 0xae, 0x46, 0x2b, 0x25, 0x9c, 0x2f, 0x42, 
  0x55, 0x37, 0xb1, 0xfa, 0x7d, 0xc6, 0xea, 0x3a, 
  0xad, 0xa1, 0x92, 0x71, 0x84, 0xfd, 0xf5, 0xdc, 
  0xde, 0x04, 0xff, 0x6a, 0xf0, 0xb7, 0x9f, 0x2a, 
  0xf8, 0x37, 0x2b, 0x75, 0x03, 0xb8, 0xbe, 0x03, 
  0x7a, 0x61, 0xa9, 0xcb, 0x1f, 0x94, 0xf3, 0x98, 
  0xcc, 0x67, 0xb0, 0xb2, 0x6b, 0x54, 0x4a, 0xe4, 
  0x39, 0x12, 0x39, 0xa5, 0xa9, 0xd6, 0xb1, 0xb7, 
  0xdb, 0x6f, 0xbc, 0x65, 0xdf, 0x7f, 0xd9, 0x2d, 
  0xfb, 0x71, 0x92, 0x33, 0xad, 0x86, 0x9a, 0x76, 
  0xfd, 0xad, 0xb7, 0xeb, 0x9d, 0xa6, 0x5d, 0x7f, 
  0xea, 0x76, 0xbd, 0xdd, 0x69, 0xfa, 0xf5, 0x62, 
  0x87, 0x7f, 0x61, 0x1d, 0x47, 0x91, 0xf4, 0x80, 
  0x57, 0xf3, 0xf9, 0x9f, 0x9c, 0x25, 0xa4, 0x51, 
  0x4a, 0xfa, 0xae, 0x0f, 0x68, 0x8e, 0xfc, 0x4d, 
  0x7b, 0xde, 0xb4, 0xe7, 0xe5, 0x22, 0x94, 0xc6, 
  0x46, 0x3e, 0x4a, 0x80, 0x1e, 0x2f, 0x47, 0x26, 
  0x9a, 0x8d, 0x40, 0x20, 0x92, 0x76, 0xe6, 0x88, 
  0x25, 0x7f, 0x28, 0x4f, 0x98, 0x81, 0xb0, 0x09, 
  0xd8, 0x17, 0xd6, 0xa3, 0xaf, 0xe5, 0xf3, 0x26, 
  0x01, 0x3c, 0x5b, 0x8b, 0x5e, 0x57, 0x02, 0xe0, 
  0x33, 0x7a, 0xab, 0x1f, 0xa7, 0x46, 0x1f, 0xa4, 
  0xb4, 0x9b, 0x22, 0xdd, 0xc4, 0xfc, 0xeb, 0x8e, 
  0xf9, 0x4e, 0x33, 0x96, 0x7b, 0x35, 0x63, 0xb9, 
  0xf6, 0xb3, 0x8e, 0xe5, 0xf6, 0xdf, 0xee, 0x58, 
  0x6e, 0xc2, 0x84, 0x3d, 0x15, 0xfe, 0x0b, 0x21, 
  0x99, 0x57, 0x0a, 0x92, 0x55, 0x96, 0x97, 0x39, 
  0xa7, 0xbb, 0x04, 0x6d, 0x13, 0xb0, 0x55, 0x16, 
  0x3a, 0xbd, 0x93, 0x0b, 0x7d, 0x2b, 0x56, 0x01, 
  0x9b, 0x99, 0xdd, 0x6b, 0x9f, 0xd9, 0xed, 0x37, 
  0x33, 0xbb, 0x27, 0x9f, 0xd9, 0xfd, 0xd4, 0xcc, 
  0xec, 0x8a, 0x35, 0x04, 0x13, 0x39, 0x05, 0xb2, 
  0x48, 0xc6, 0xf5, 0xb6, 0x04, 0x59, 0x5a, 0x04, 
  0x64, 0xe4, 0xfd, 0xdb, 0x35, 0xa4, 0x79, 0xbd, 
  0xa6, 0x99, 0xdf, 0x35, 0xf3, 0xbb, 0x8a, 0xd1, 
  0x1a, 0x8c, 0xa8, 0x18, 0xc2, 0x22, 0x86, 0x1e, 
  0x2f, 0x5e, 0x05, 0x25, 0xc6, 0x7a, 0x76, 0xf3, 
  0x36, 0xdc, 0x8b, 0xed, 0xe4, 0x5d, 0x99, 0xbd, 
  0xc9, 0x00, 0xcd, 0x3b, 0x36, 0xaf, 0xb7, 0x99, 
  0xef, 0xd4, 0xd1, 0xcc, 0xbb, 0x24, 0x71, 0x4b, 
  0x51, 0x5a, 0xbd, 0x0e, 0x26, 0xd6, 0x18, 0xc8, 
  0xf9, 0x6e, 0x8c, 0x06, 0x09, 0x65, 0x42, 0x15, 
  0x50, 0xbc, 0xf9, 0x2b, 0xab, 0xcf, 0x59, 0xbd, 
  0x58, 0xfd, 0x90, 0x6c, 0x89, 0x40, 0xa7, 0x96, 
  0x2f, 0xaf, 0x0a, 0x4e, 0x3c, 0x96, 0xab, 0x57, 
  0x28, 0x05, 0x90, 0x7e, 0x76, 0x63, 0xbb, 0x5d, 
  0xe7, 0xf3, 0x80, 0xa1, 0x19, 0x7b, 0x01, 0x97, 
  0xe5, 0x7c, 0xa2, 0xf2, 0xd0, 0xa4, 0x44, 0xa1, 
  0x71, 0x41, 0xef, 0xeb, 0x4a, 0x59, 0xf0, 0x88, 
  0xea, 0xea, 0xe0, 0x0a, 0x65, 0xcd, 0x55, 0xca, 
  0x6c, 0xed, 0x0f, 0xc6, 0xdb, 0x9e, 0xfe, 0x8c, 
  0x81, 0x5e, 0x30, 0xef, 0x3f, 0xf2, 0xb0, 0xaf, 
  0x7a, 0x7e, 0x28, 0x24, 0xf8, 0x1a, 0xf7, 0x96, 
  0x32, 0x49, 0xbe, 0x36, 0xc5, 0x3e, 0x88, 0xb0, 
  0x30, 0x6a, 0xf7, 0x54, 0xf4, 0x50, 0xce, 0x07, 
  0x8b, 0xdd, 0x2c, 0x99, 0x78, 0x33, 0x16, 0x0e, 
  0xc1, 0xdc, 0x8f, 0x95, 0x1e, 0xde, 0x46, 0x0a, 
  0x74, 0x24, 0x85, 0xb6, 0xdc, 0x78, 0xc9, 0xfb, 
  0x87, 0x23, 0xe0, 0xd1, 0x3c, 0xf8, 0xbb, 0xad, 
  0x07, 0x3b, 0xb7, 0xe2, 0xf7, 0xb0, 0xbf, 0x94, 
  0x3a, 0x9c, 0xe8, 0x95, 0x9b, 0x29, 0x4f, 0x0b, 
  0x09, 0xba, 0xad, 0xa5, 0x4f, 0x9d, 0xff, 0x07, 
  0x09, 0x7b, 0x71, 0x4f, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x28, 0x75, 0x75, 0x61, 0x79, 0x29, 0x77, 
  0x6e, 0x63, 0x6b, 0x6c, 0x65, 0x74, 0x2f, 0x00, 
  0x02, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 
  0x08, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 
  0x6f, 0x72, 0x67, 0x2f, 0x09, 0x00, 0x00, 0x00, 
  0x61, 0x70, 0x70, 0x6c, 0x65, 0x74, 0x2f, 0x00, 
  0x04, 0x00, 0x00, 0x00, 0x77, 0x6f, 0x72, 0x6b, 
  0x73, 0x70, 0x61, 0x63, 0x65, 0x2d, 0x73, 0x77, 
  0x69, 0x74, 0x63, 0x68, 0x65, 0x72, 0x2e, 0x75, 
  0x69, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x6a, 0x42, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x78, 0xda, 0xed, 0x5c, 0xdd, 0x73, 0xdb, 0x28, 
  0x10, 0x7f, 0xef, 0x5f, 0xa1, 0xe3, 0xf5, 0xc6, 
  0x8d, 0x95, 0x5e, 0x3b, 0x73, 0x1d, 0x47, 0x9d, 
  0xe4, 0x9a, 0x7e, 0x4c, 0xdb, 0xb4, 0x13, 0xe7, 
  0xda, 0x47, 0x06, 0x4b, 0xd8, 0xa2, 0xc6, 0xa0, 
  0x03, 0x64, 0x27, 0x37, 0xf7, 0xc7, 0x1f, 0x48, 
  0x8e, 0x23, 0xdb, 0x58, 0x42, 0x1f, 0x49, 0xdc, 
  0x8c, 0xdf, 0x62, 0xc1, 0xae, 0x76, 0x17, 0xf6, 
  0xb7, 0xcb, 0x2e, 0xca, 0xe0, 0xcd, 0xf5, 0x8c, 
  0x7a, 0x73, 0x2c, 0x24, 0xe1, 0xec, 0x04, 0xf8, 
  0xcf, 0xfb, 0xe0, 0x4d, 0xf0, 0x6c, 0x40, 0x98, 
  0xc2, 0x62, 0x8c, 0x42, 0x1c, 0x3c, 0xf3, 0xbc, 
  0x81, 0xc0, 0xff, 0xa4, 0x44, 0x60, 0xe9, 0x51, 
  0x32, 0x3a, 0x01, 0x13, 0x35, 0xfd, 0x1d, 0xdc, 
  0x91, 0x1c, 0x3f, 0xf7, 0x5f, 0x81, 0xa3, 0x6c, 
  0xde, 0x6f, 0xbd, 0x9e, 0xb7, 0xa2, 0xec, 0x31, 
  0x34, 0x23, 0x6c, 0xd2, 0x4b, 0x38, 0x25, 0xe1, 
  0x8d, 0xa7, 0x78, 0x42, 0xf1, 0x1c, 0xd3, 0x5e, 
  0xc8, 0xf5, 0x8c, 0x6b, 0x95, 0x22, 0xea, 0xf5, 
  0x7a, 0x19, 0x19, 0x1f, 0xfd, 0xc4, 0xa1, 0xf2, 
  0x42, 0x8a, 0xa4, 0x3c, 0x01, 0xef, 0xd5, 0xf4, 
  0x2d, 0x41, 0x94, 0x4f, 0x80, 0x47, 0xa2, 0x13, 
  0x90, 0xa0, 0x09, 0x16, 0x30, 0x11, 0x3c, 0xc1, 
  0x42, 0x11, 0x2c, 0x61, 0x94, 0x0f, 0x1a, 0x4a, 
  0x4d, 0xbb, 0x1c, 0xb8, 0xf1, 0xf4, 0xdb, 0xf0, 
  0x09, 0x18, 0x71, 0x11, 0xe9, 0xe9, 0x0b, 0x12, 
  0xa9, 0x18, 0x04, 0x2f, 0x07, 0x47, 0xb7, 0xe3, 
  0xf6, 0xe9, 0x8a, 0x28, 0x8a, 0x81, 0xa7, 0x04, 
  0x62, 0x92, 0x22, 0x85, 0x46, 0x54, 0x3f, 0xbc, 
  0xc1, 0x12, 0x04, 0x3f, 0xb8, 0x98, 0xca, 0x44, 
  0xab, 0xe1, 0x0d, 0x17, 0x44, 0x85, 0x31, 0x16, 
  0xde, 0x37, 0x81, 0xc7, 0x58, 0x60, 0x16, 0x62, 
  0x59, 0xc5, 0x57, 0xdb, 0x8a, 0xfc, 0x6b, 0xb8, 
  0x81, 0xe0, 0x1d, 0xa2, 0x12, 0x57, 0xca, 0x71, 
  0x93, 0x60, 0x18, 0x6b, 0xd3, 0x81, 0x80, 0x71, 
  0x31, 0x43, 0x74, 0x8b, 0x20, 0x8c, 0x09, 0x8d, 
  0x72, 0xe3, 0x32, 0xa4, 0x8d, 0x68, 0x7e, 0x9e, 
  0x80, 0xf9, 0x88, 0x5f, 0x2f, 0x2d, 0x61, 0xb3, 
  0xe3, 0xf7, 0x33, 0x3d, 0x9c, 0x59, 0x31, 0x37, 
  0x5a, 0xcf, 0xcc, 0xf7, 0x57, 0x04, 0xdb, 0x72, 
  0xcc, 0x89, 0x24, 0x99, 0xd4, 0x57, 0x22, 0xdd, 
  0x12, 0xda, 0x46, 0xc0, 0x05, 0xc1, 0x4c, 0x21, 
  0xa5, 0x77, 0x02, 0x08, 0xe6, 0x66, 0x85, 0xc2, 
  0x6d, 0xe1, 0x6d, 0x84, 0xc6, 0xb6, 0x7a, 0x77, 
  0x80, 0xe0, 0xd8, 0x3a, 0x3b, 0xd3, 0xef, 0xee, 
  0x77, 0xb9, 0x72, 0x46, 0xab, 0x63, 0x50, 0x9c, 
  0xdd, 0x40, 0xb3, 0x06, 0xbb, 0xa9, 0xb5, 0x51, 
  0x4a, 0x0d, 0xe3, 0x1f, 0xef, 0x24, 0xd9, 0xb2, 
  0x8e, 0xdd, 0x42, 0xef, 0x84, 0xe6, 0x98, 0x9b, 
  0x68, 0x6c, 0xfe, 0xf4, 0xc1, 0x26, 0x4d, 0x43, 
  0x3b, 0xd9, 0x08, 0xb5, 0x6f, 0x33, 0xa5, 0x1d, 
  0xe7, 0xfd, 0xdb, 0x4f, 0xf0, 0xdb, 0xd7, 0x8f, 
  0x17, 0x57, 0xe7, 0x97, 0xf0, 0xcb, 0xd7, 0xab, 
  0x8f, 0x5f, 0x2f, 0xe0, 0x97, 0xd3, 0xe1, 0x27, 
  0xef, 0x3f, 0xcf, 0x32, 0xf2, 0x41, 0xff, 0x2a, 
  0x0e, 0x9f, 0xfd, 0x7d, 0x75, 0xa5, 0x1f, 0x7f, 
  0xbb, 0x3c, 0x1f, 0x0e, 0x2d, 0xcf, 0x2f, 0xcf, 
  0x3f, 0x9f, 0x9f, 0x0e, 0xcf, 0xb3, 0x91, 0x3a, 
  0xb2, 0x51, 0x34, 0xc2, 0x14, 0x5e, 0x23, 0x4a, 
  0x26, 0x7a, 0x45, 0xfa, 0x75, 0x48, 0x65, 0x8c, 
  0x22, 0xbe, 0x80, 0xc6, 0x41, 0x8d, 0x6f, 0xb2, 
  0x72, 0x9b, 0x58, 0x17, 0xc6, 0xbe, 0x38, 0xa7, 
  0x46, 0x98, 0x99, 0xb6, 0x59, 0xbe, 0x40, 0xe8, 
  0xf6, 0xe7, 0x31, 0xb0, 0xd1, 0xb7, 0x58, 0xa8, 
  0x7d, 0x5f, 0x2c, 0xeb, 0x82, 0xe1, 0xb1, 0x82, 
  0x09, 0x8a, 0xa2, 0x0a, 0x4f, 0xa8, 0x36, 0xbc, 
  0x0b, 0x76, 0xbc, 0x04, 0xbb, 0x28, 0x5b, 0x9a, 
  0xbd, 0x35, 0x38, 0x38, 0x01, 0xc5, 0x2b, 0x27, 
  0xea, 0x52, 0x0b, 0xd9, 0xad, 0x74, 0x89, 0x22, 
  0xc2, 0xcf, 0x52, 0xa5, 0xb4, 0xa8, 0x99, 0xb1, 
  0xc2, 0x54, 0xe8, 0xf8, 0xa7, 0x20, 0x67, 0xf4, 
  0x06, 0x0a, 0x33, 0x0a, 0xca, 0x38, 0xee, 0x70, 
  0x44, 0x6b, 0xbc, 0x1d, 0xc6, 0x7c, 0xe1, 0x65, 
  0x8c, 0x3d, 0x15, 0x63, 0x6f, 0xf9, 0x26, 0x6f, 
  0x71, 0x1b, 0x86, 0x5d, 0x74, 0xec, 0x64, 0xbd, 
  0x6c, 0x4c, 0x42, 0xc4, 0xe0, 0x98, 0x87, 0xa9, 
  0x6c, 0xc7, 0x46, 0xe0, 0x10, 0x93, 0xb9, 0x49, 
  0x61, 0xf0, 0x18, 0xa5, 0x54, 0xed, 0x48, 0x0e, 
  0x5c, 0xd9, 0xa5, 0x12, 0xc3, 0x94, 0xe9, 0x00, 
  0x45, 0x09, 0x6b, 0xa9, 0x60, 0x24, 0xd0, 0x02, 
  0x12, 0x16, 0xe9, 0xbd, 0xa8, 0xb8, 0xa8, 0xc3, 
  0x6b, 0x70, 0x94, 0x6f, 0x9b, 0xd2, 0x39, 0x7a, 
  0x01, 0xa7, 0x7a, 0xab, 0xd6, 0x93, 0x09, 0x5f, 
  0x27, 0x88, 0x45, 0x2d, 0x6d, 0x34, 0x26, 0x94, 
  0xb6, 0x64, 0x91, 0x70, 0x49, 0x72, 0x6f, 0xed, 
  0xbb, 0x9a, 0xa4, 0x52, 0xdf, 0xc1, 0x51, 0x85, 
  0x3b, 0x36, 0x71, 0xd7, 0x0f, 0x2b, 0x50, 0x8b, 
  0x35, 0xa8, 0xfd, 0x09, 0x1e, 0xc1, 0x51, 0x1c, 
  0x92, 0x97, 0xfa, 0x9a, 0x3a, 0x82, 0x13, 0xa2, 
  0x14, 0xae, 0xe0, 0x42, 0x3a, 0xc1, 0x53, 0x13, 
  0x88, 0xd2, 0xaf, 0xb9, 0x43, 0x25, 0xa9, 0x33, 
  0xf2, 0xd7, 0xae, 0x9a, 0x76, 0x66, 0xf5, 0x0e, 
  0x21, 0xea, 0x1e, 0x60, 0xaa, 0x63, 0xa8, 0xea, 
  0x16, 0xae, 0xec, 0xfc, 0x26, 0x82, 0xa7, 0x09, 
  0x08, 0xb6, 0xc3, 0x9b, 0x3b, 0x53, 0x17, 0x1c, 
  0x74, 0xc7, 0xc2, 0xce, 0xf0, 0xb0, 0x23, 0x4c, 
  0xec, 0x04, 0x17, 0x1d, 0xb1, 0xd1, 0x09, 0x1f, 
  0xdb, 0x20, 0xc7, 0x3a, 0x4e, 0xfa, 0x7d, 0xf0, 
  0x88, 0x6e, 0x5b, 0x2f, 0x89, 0xab, 0xa7, 0xb9, 
  0x5d, 0xfb, 0x61, 0x42, 0x58, 0x11, 0x36, 0x59, 
  0x3a, 0x83, 0x82, 0x2f, 0x24, 0x94, 0x7a, 0x00, 
  0xb8, 0xf0, 0xec, 0xd0, 0x1c, 0x1d, 0x23, 0x99, 
  0x8d, 0x1d, 0x8a, 0x7e, 0xa6, 0x52, 0x65, 0x07, 
  0xad, 0x60, 0xa5, 0xeb, 0xdd, 0xc3, 0xd6, 0xd2, 
  0x52, 0x32, 0x1b, 0x69, 0xb0, 0x50, 0x5a, 0x7b, 
  0xbf, 0x2d, 0x33, 0x2d, 0x1f, 0x16, 0x24, 0x6c, 
  0xa2, 0xb8, 0x2b, 0xfe, 0xd4, 0xc3, 0xa0, 0xce, 
  0xfc, 0xbe, 0x86, 0xef, 0x3b, 0xfb, 0x7f, 0x5b, 
  0x4f, 0xf8, 0x9c, 0x47, 0x7a, 0xe3, 0x04, 0x79, 
  0x81, 0x40, 0x6f, 0x0d, 0x18, 0x72, 0xba, 0x0f, 
  0x4e, 0xe0, 0x54, 0xab, 0x68, 0x97, 0xce, 0x18, 
  0x47, 0x68, 0xcb, 0xdd, 0x78, 0x11, 0x19, 0xdf, 
  0xe8, 0xd0, 0x89, 0x4d, 0x65, 0xb2, 0x2d, 0xbb, 
  0x19, 0xc3, 0x33, 0xce, 0x48, 0x68, 0x2a, 0x6e, 
  0x13, 0x5c, 0x74, 0x58, 0x03, 0x4e, 0xfb, 0xea, 
  0x10, 0x8d, 0x03, 0x73, 0x87, 0xc1, 0xb9, 0xdc, 
  0x51, 0xfd, 0xc7, 0x76, 0xd4, 0xfb, 0xcf, 0x8e, 
  0x1a, 0x29, 0xdb, 0x5d, 0x36, 0x72, 0x7f, 0xc7, 
  0xe0, 0xda, 0x8a, 0xb5, 0x3f, 0x7e, 0x96, 0x2b, 
  0x53, 0x42, 0xbc, 0x9b, 0x70, 0x27, 0xd1, 0xb2, 
  0xb1, 0x61, 0xea, 0xab, 0xb7, 0x60, 0xe5, 0x56, 
  0x3f, 0xdd, 0x44, 0xef, 0x43, 0xdd, 0xb4, 0xfc, 
  0xf0, 0xba, 0xec, 0x62, 0x55, 0x72, 0x44, 0x4a, 
  0x09, 0x32, 0x4a, 0x15, 0x96, 0x3b, 0xb7, 0xc7, 
  0x6a, 0xca, 0xf2, 0xad, 0x0b, 0x4c, 0x26, 0xb1, 
  0x02, 0xde, 0x1c, 0xd1, 0x34, 0xeb, 0x9a, 0xd0, 
  0x28, 0x6f, 0x08, 0xda, 0x76, 0x48, 0x39, 0xff, 
  0xda, 0x3b, 0x68, 0x17, 0xc1, 0x6e, 0x67, 0x6b, 
  0x0c, 0xdf, 0x8d, 0x12, 0xa1, 0x1d, 0xde, 0x68, 
  0xd5, 0xa6, 0x41, 0x5f, 0xa7, 0x50, 0xf0, 0xc8, 
  0x5a, 0x3c, 0x87, 0x0e, 0xcf, 0xfe, 0x77, 0x78, 
  0xfc, 0x03, 0x52, 0x3d, 0x74, 0x87, 0xc7, 0x3f, 
  0x74, 0x78, 0x1c, 0x4a, 0x21, 0x7f, 0x3c, 0xf1, 
  0x92, 0x71, 0x21, 0x65, 0x30, 0x07, 0x8b, 0x02, 
  0x76, 0xee, 0x4e, 0x3c, 0x1e, 0xa8, 0x0e, 0xd4, 
  0xe8, 0xbc, 0xe7, 0x1e, 0xfd, 0x2f, 0xd2, 0xd9, 
  0x08, 0x0b, 0x8f, 0x8f, 0xbd, 0x82, 0xd6, 0xaf, 
  0xf7, 0xa8, 0xa2, 0xdb, 0xe2, 0x20, 0xe9, 0x74, 
  0x88, 0x2c, 0xac, 0x75, 0xbd, 0xa3, 0xe4, 0xa1, 
  0xae, 0xfb, 0xcb, 0xd4, 0x75, 0x6d, 0x95, 0xcd, 
  0x8d, 0x75, 0x07, 0x4f, 0xa3, 0x43, 0xb3, 0x59, 
  0xd3, 0x2c, 0x68, 0xd9, 0xac, 0xb2, 0xd9, 0x59, 
  0x55, 0xb3, 0xa3, 0x8a, 0xe6, 0xa1, 0x5e, 0x70, 
  0x68, 0x9b, 0x3f, 0x54, 0xdb, 0xbc, 0x90, 0x15, 
  0xac, 0xfc, 0x08, 0x1a, 0x1d, 0xdc, 0xd2, 0x82, 
  0x7b, 0x49, 0x8a, 0x6a, 0xa7, 0x03, 0xee, 0xa9, 
  0xc0, 0xdd, 0xc5, 0x56, 0x86, 0xe0, 0xac, 0x46, 
  0x16, 0x70, 0x8f, 0xd7, 0x4f, 0xb6, 0x42, 0x76, 
  0x01, 0xd0, 0x94, 0xc0, 0x18, 0xce, 0x09, 0x5e, 
  0x1c, 0xee, 0xa3, 0x3c, 0x5a, 0x41, 0xb0, 0x99, 
  0x63, 0x0d, 0x43, 0xc1, 0x29, 0xc5, 0xd1, 0x0f, 
  0xc2, 0xf4, 0x01, 0xdb, 0xee, 0x61, 0x32, 0x9b, 
  0x53, 0xd3, 0xc5, 0xe2, 0xac, 0xde, 0x04, 0xcd, 
  0xad, 0x74, 0x2c, 0xf5, 0x6e, 0xf1, 0xfb, 0xfd, 
  0xa7, 0x70, 0x3d, 0x2c, 0xce, 0x8d, 0x31, 0x42, 
  0x02, 0xe6, 0x77, 0xe6, 0x41, 0x80, 0x52, 0xc5, 
  0x67, 0xfa, 0x24, 0x19, 0x36, 0xd6, 0xef, 0x1e, 
  0x78, 0xae, 0x15, 0x4c, 0xdc, 0x73, 0xe9, 0xa6, 
  0x69, 0xdd, 0x95, 0x06, 0x80, 0xef, 0xda, 0xff, 
  0xb7, 0x0a, 0x5e, 0x2b, 0x64, 0x78, 0x22, 0x59, 
  0x9d, 0xe2, 0x9c, 0x2a, 0x92, 0x40, 0xf3, 0x75, 
  0x44, 0x05, 0x74, 0x5f, 0x18, 0xe7, 0x69, 0xf3, 
  0xae, 0x18, 0x23, 0x8d, 0xdc, 0x12, 0xae, 0xec, 
  0x50, 0xf3, 0xd8, 0xe0, 0x96, 0xa0, 0xed, 0x49, 
  0xe3, 0xe4, 0x78, 0xbf, 0x71, 0xf2, 0xaf, 0x18, 
  0x87, 0xd3, 0xe2, 0xc1, 0x65, 0x1d, 0x24, 0xa1, 
  0xe2, 0x93, 0x09, 0xc5, 0xdd, 0xde, 0xb4, 0x5d, 
  0xbd, 0xc2, 0xcb, 0x81, 0xd8, 0x23, 0xcc, 0x93, 
  0x8e, 0x2d, 0x82, 0x5f, 0x01, 0x4b, 0x0f, 0x57, 
  0x6d, 0x7f, 0xed, 0xd4, 0xe6, 0xc5, 0xa1, 0xd7, 
  0x59, 0xd2, 0xeb, 0x3c, 0x74, 0x10, 0xdc, 0x8e, 
  0x38, 0xf2, 0xd0, 0xed, 0x6c, 0x74, 0x7a, 0x70, 
  0x6f, 0x5a, 0xda, 0x04, 0xb2, 0x0b, 0x53, 0x5b, 
  0x10, 0x8b, 0x10, 0x5b, 0x02, 0xec, 0xf8, 0x2c, 
  0x12, 0x85, 0x86, 0x33, 0x44, 0x02, 0x23, 0x50, 
  0xfe, 0x11, 0xe1, 0x87, 0x3c, 0xee, 0x6e, 0x7e, 
  0x27, 0x59, 0x60, 0xe0, 0x77, 0xf2, 0x61, 0xa1, 
  0x63, 0x67, 0xb7, 0x98, 0x05, 0x44, 0x9c, 0x61, 
  0x38, 0xca, 0x1f, 0x38, 0x36, 0x40, 0x41, 0x30, 
  0x51, 0xd3, 0x5e, 0x48, 0x79, 0xbd, 0x46, 0x76, 
  0xe3, 0x8e, 0x70, 0x8d, 0x60, 0x6d, 0x23, 0x5d, 
  0xc5, 0xe6, 0xba, 0xc4, 0x31, 0x92, 0xcd, 0x89, 
  0x1b, 0xa4, 0x06, 0xb6, 0x74, 0x40, 0x2a, 0x1e, 
  0x4e, 0xab, 0xde, 0xfe, 0x88, 0xb7, 0x13, 0x1c, 
  0xc3, 0xf1, 0xde, 0xe2, 0x83, 0x93, 0xe2, 0x5b, 
  0xd2, 0x6b, 0xce, 0xcb, 0x83, 0x29, 0x66, 0x91, 
  0x33, 0x55, 0x55, 0xa9, 0xb2, 0x1a, 0x8a, 0xd6, 
  0xf5, 0x5c, 0x1b, 0x1c, 0xe4, 0x60, 0xd2, 0xcb, 
  0x6b, 0x5b, 0xab, 0x38, 0xb0, 0xfe, 0xd8, 0x13, 
  0x58, 0x26, 0x9c, 0x49, 0x2d, 0x4d, 0xcf, 0xd7, 
  0x90, 0x13, 0x63, 0x9a, 0x2c, 0x9d, 0x5f, 0x07, 
  0x91, 0xe2, 0xcc, 0x4a, 0xfa, 0x3e, 0x08, 0x0a, 
  0xd0, 0x61, 0xa5, 0xde, 0x78, 0x98, 0xc9, 0x54, 
  0xd4, 0xc0, 0x72, 0x97, 0xe1, 0xae, 0xe3, 0x60, 
  0xeb, 0xad, 0x14, 0x1b, 0x12, 0xd6, 0x0f, 0xdc, 
  0xb3, 0x60, 0x69, 0xd9, 0x53, 0x5b, 0x30, 0xc6, 
  0x17, 0x58, 0x38, 0xcc, 0x4b, 0x93, 0xc4, 0xcc, 
  0x7b, 0xf1, 0xaa, 0x6a, 0xa2, 0x54, 0x38, 0xd1, 
  0xe9, 0x76, 0x28, 0x70, 0x2e, 0x5d, 0x25, 0x67, 
  0xf3, 0xff, 0x06, 0xd6, 0x08, 0x36, 0xf6, 0x44, 
  0x7d, 0x3b, 0x6d, 0xdc, 0x38, 0x7f, 0x58, 0x0b, 
  0xf9, 0x8f, 0x69, 0xa1, 0xc1, 0x51, 0xe1, 0xff, 
  0x48, 0xfc, 0x0f, 0x89, 0xff, 0x8d, 0xe8, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x28, 0x75, 0x75, 0x61, 0x79, 0x29, 0x77, 
  0x6f, 0x72, 0x6b, 0x73, 0x70, 0x61, 0x63, 0x65, 
  0x2d, 0x73, 0x77, 0x69, 0x74, 0x63, 0x68, 0x65, 
  0x72, 0x2d, 0x6d, 0x65, 0x6e, 0x75, 0x2e, 0x78, 
  0x6d, 0x6c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x48, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x78, 0xda, 0xb3, 0xc9, 0x4d, 0xcd, 0x2b, 0xcd, 
  0x2c, 0x49, 0xcd, 0x55, 0xc8, 0x4b, 0xcc, 0x4d, 
  0xb5, 0x55, 0x0a, 0x48, 0x4c, 0x4f, 0x2d, 0x52, 
  0x08, 0x28, 0x4a, 0x4d, 0x4b, 0x2d, 0x4a, 0xcd, 
  0x4b, 0x4e, 0x2d, 0x56, 0xf0, 0x04, 0x4a, 0x2a, 
  0x29, 0x24, 0x26, 0x97, 0x64, 0xe6, 0xe7, 0x41, 
  0xe5, 0x91, 0xa4, 0x95, 0x14, 0xf4, 0xed, 0xb8, 
  0x80, 0x00, 0x00, 0xb1, 0xc1, 0x18, 0x48, 0x00, 
  0x00, 0x28, 0x75, 0x75, 0x61, 0x79, 0x29, 0x67, 
  0x6e, 0x6f, 0x6d, 0x65, 0x2f, 0x00, 0x00, 0x00, 
  0x01, 0x00, 0x00, 0x00
} };

static GStaticResource static_resource = { wncklet_resource_data.data, sizeof (wncklet_resource_data.data), NULL, NULL, NULL };
extern GResource *wncklet_get_resource (void);
GResource *wncklet_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a sane way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif


#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
